#!/bin/sh

# generated.pot is automatically generated by ArchGenXML and manual.pot is manually created
#i18ndude rebuild-pot --pot windowZ.pot --create windowZ --merge generated.pot --merge2 manual.pot ../
i18ndude merge --pot windowZ.pot --merge generated.pot --merge2 manual.pot
i18ndude sync --pot  windowZ.pot windowZ-??.po
i18ndude sync --pot  windowZ.pot windowZ-??-??.po

# windowZ-plone.pot is manually created
i18ndude sync --pot  windowZ-plone.pot windowZ-plone-*.po
